Stan Math Library: stan/math/prim/mat/fun/num_elements.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
num_elements.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
int | stan::math::num_elements (const T &x)
| Returns 1, the number of elements in a primitive type. More...
template<typename T , int R, int C>
int | stan::math::num_elements (const Eigen::Matrix< T, R, C > &m)
| Returns the size of the specified matrix. More...
template<typename T >
int | stan::math::num_elements (const std::vector< T > &v)
| Returns the number of elements in the specified vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.